Hooks
=======

plugin manager subpackage, handles calling the build plugins
and defines the hooks spec, that build plugins can implement

.. automodule:: drain_swamp.monkey.hooks
   :members:
   :undoc-members:
   :platform: Unix
   :synopsis: plugin manager subpackage exports

.. tableofcontents::
